@@ -40,7 +40,7 @@
 #'   specification of the obsered (in contrast to manipulated) variables.
 #' @param formula A formula specifying the ANOVA model similar to
 #'   \code{\link{aov}} (for \code{aov_car} or similar to \code{lme4:lmer} for
-#'   \code{aov_4}). Should include an error term (i.e., \code{Error(id/...)} for
+#'   \code{aov_4}). Must include an error term (i.e., \code{Error(id/...)} for
 #'   \code{aov_car} or \code{(...|id)} for \code{aov_4}). Note that the
 #'   within-subject factors do not need to be outside the Error term (this
 #'   contrasts with \code{aov}). See Details.
@@ -361,6 +361,10 @@ aov_car <- function(formula,
          domain = NA)
 
   # from here, code by Henrik Singmann:
+  if (is.null(indError)) {
+    stop("formula needs an error term identifying the ID column.")
+  }
+  
   vars <- all.vars(formula)
   #--- Russ Lenth added/modified code to detect transformed responses:
   lhs <- all.names(formula[[2]])
@@ -483,6 +487,25 @@ aov_car <- function(formula,
     }
   }
   
+  ## check for structurally missing data
+  # within-subjects
+  if ((length(within) > 0) && any(table(data[within]) == 0)) {
+    stop("Empty cells in within-subjects design ", 
+         " (i.e., bad data structure).\n", 
+         "", paste0("table(data[", deparse(within), "])"), "\n# ",
+         paste(utils::capture.output(table(data[within])), collapse = "\n# "),
+         call. = FALSE)
+  }
+  # between-subjects
+  between_nn <- between[!vapply(data[between], is.numeric, NA)]
+  if (length(between_nn) > 0 && any(table(data[between_nn]) == 0)) {
+    stop("Empty cells in between-subjects design ", 
+         " (i.e., bad data structure).\n",  
+         "", paste0("table(data[", deparse(between_nn), "])"), "\n# ",
+         paste(utils::capture.output(table(data[between_nn])), collapse = "\n# "),
+         call. = FALSE)
+  }
+  
   # Is fun_aggregate NULL and aggregation necessary?
   if (is.null(fun_aggregate)) {
     if (any(xtabs(
@@ -495,7 +518,6 @@ aov_car <- function(formula,
   } 
   
   # prepare the data:
-  
   tmp.dat <- do.call(
     dcast, 
     args = 
@@ -539,6 +561,9 @@ aov_car <- function(formula,
     if (check_contrasts) {
       resetted <- NULL
       for (i in between) {
+        if (is.character(tmp.dat[,i])) {
+          tmp.dat[,i] <- factor(tmp.dat[,i])
+        }
         if (is.factor(tmp.dat[,i])) {
           if (is.null(attr(tmp.dat[,i], "contrasts")) & 
               (options("contrasts")[[1]][1] != "contr.sum")) {
