@@ -1,6 +1,6 @@
 ## ----set-options, echo=FALSE, cache=FALSE-----------------------------------------------
 options(width = 90)
-knitr::opts_chunk$set(dpi=80)
+knitr::opts_chunk$set(dpi=72)
 
 ## ----message=FALSE, warning=FALSE-------------------------------------------------------
 library("afex")     
@@ -29,13 +29,13 @@ plot_grid(
   p_an + theme_bw() + theme(legend.position="bottom"),
   p_an + theme_light() + theme(legend.position="bottom"),
   p_an + theme_minimal() + theme(legend.position="bottom"),
-  p_an + jtools::theme_apa() + theme(legend.position="bottom"),
+  p_an + jtools::theme_nice() + theme(legend.position="bottom"),
   p_an + ggpubr::theme_pubr(),
   p_an + theme_cowplot() + theme(legend.position="bottom"),
   labels = "AUTO"
 )  
 
-## ----fig.width=3.5, fig.height=3, dpi = 150, out.width='50%'----------------------------
+## ----fig.width=3.5, fig.height=3, dpi = 100, out.width='50%'----------------------------
 p_an + 
   scale_y_continuous(breaks=seq(400, 900, length.out = 3)) +
   theme_bw(base_size = 15) + 
@@ -50,13 +50,13 @@ theme_set(theme_bw(base_size = 15) +
 ## ---- eval=FALSE------------------------------------------------------------------------
 #  ggsave("my_plot.png", device = "png",
 #         width = 9, height = 8, units = "cm",
-#         dpi = 600) ## the higher the dpi, the better the resolution
+#         dpi = 600) ## the larger the dpi, the better the resolution
 
 ## ---- eval=FALSE------------------------------------------------------------------------
 #  ggsave("my_plot.pdf", device = "pdf",
 #         width = 9, height = 8, units = "cm")
 
-## ----fig.width=8.5, fig.height=12, dpi = 150--------------------------------------------
+## ----fig.width=8.5, fig.height=12, dpi = 125--------------------------------------------
 p1 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", dodge = 0.3,
                 data_arg = list(
                   position = 
@@ -72,24 +72,26 @@ p2 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", dodge = 0.5,
                   dodge.width = 0.5,  ## needs to be same as dodge
                   cex = 0.8,
                   color = "darkgrey"))
-p3 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", 
-          data_geom = ggplot2::geom_violin, 
-          data_arg = list(width = 0.5))
+p3 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", dodge = 0.5,
+                data_geom = geom_count)
 p4 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", 
-          data_geom = ggplot2::geom_boxplot, 
-          data_arg = list(width = 0.3))
-p5 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", dodge = 0.7, 
-          data_geom = ggpol::geom_boxjitter, 
-          data_arg = list(
-            width = 0.5, 
-            jitter.width = 0,
-            jitter.height = 10,
-            outlier.intersect = TRUE),
-          point_arg = list(size = 2.5), 
-          error_arg = list(size = 1.5, width = 0))
-plot_grid(p1, p2, p3, p4, p5, ncol = 2, labels = 1:5)  
+                data_geom = ggplot2::geom_violin, 
+                data_arg = list(width = 0.5))
+p5 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", 
+                data_geom = ggplot2::geom_boxplot, 
+                data_arg = list(width = 0.3, linetype = 1))
+p6 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", dodge = 0.7, 
+                data_geom = ggpol::geom_boxjitter, 
+                data_arg = list(
+                  width = 0.5, 
+                  jitter.width = 0,
+                  jitter.height = 10,
+                  outlier.intersect = TRUE),
+                point_arg = list(size = 2.5), 
+                error_arg = list(size = 1.5, width = 0))
+plot_grid(p1, p2, p3, p4, p5, p6, ncol = 2, labels = 1:6)  
 
-## ----fig.width=8.5, fig.height=8, dpi = 150---------------------------------------------
+## ----fig.width=8.5, fig.height=8, dpi = 125---------------------------------------------
 p2 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", dodge = 0.5,
                 mapping = c("shape", "color"),
                 data_geom = ggbeeswarm::geom_beeswarm,
@@ -117,6 +119,18 @@ p5 <- afex_plot(aw, x = "noise", trace = "angle", error = "within", dodge = 0.7,
                 error_arg = list(size = 1.5, width = 0))
 plot_grid(p2, p3, p4, p5, ncol = 2, labels = 2:5) 
 
+## ----fig.width=8.5, fig.height=4, dpi = 150---------------------------------------------
+p1 <- afex_plot(aw, x = "noise", trace = "angle", mapping = "color", 
+                error = "within", 
+                point_arg = list(size = 5), line_arg = list(size = 2),
+                error_arg = list(size = 2))
+p2 <- afex_plot(aw, x = "noise", trace = "angle", 
+                mapping = c("color", "shape", "linetype"), 
+                error = "within", 
+                point_arg = list(size = 5), line_arg = list(size = 2),
+                error_arg = list(size = 2, width = 0, linetype = 1))
+plot_grid(p1, p2, ncol = 2)
+
 ## ----fig.width=7, fig.height=3.5, message=FALSE-----------------------------------------
 po1 <- afex_plot(aw, x = "angle", mapping = "color", error = "within", 
                  data_arg = list(),
