@@ -42,7 +42,11 @@ test_that("mixed, obk.long: type 2 and LRTs", {
   a2.h <- lmer(value ~ treatment+phase +(1|id), data = obk.long, REML=FALSE)
   a2.t <- lmer(value ~ treatment +(1|id), data = obk.long, REML=FALSE)
   a2.p <- lmer(value ~ phase +(1|id), data = obk.long, REML=FALSE)
-  extract_anova <- function(anova) unlist(anova)[c("Df1", "Chisq2", "Chi Df2", "Pr(>Chisq)2" )]
+  if (packageVersion("lme4") <= "1.1.21") {
+    extract_anova <- function(anova) unlist(anova)[c("Df1", "Chisq2", "Chi Df2", "Pr(>Chisq)2" )]
+  } else {
+    extract_anova <- function(anova) unlist(anova)[c("npar1", "Chisq2", "Df2", "Pr(>Chisq)2" )]
+  }
   
   expect_that(
     unlist(t2$anova_table[3,])
@@ -311,16 +315,16 @@ test_that("mixed with all available methods", {
   testthat::skip_on_cran()
   sk2_aff <- droplevels(sk2011.2[sk2011.2$what == "affirmation",])
   for (i in c(2, 3)) {
-    sk2_aff_kr <- mixed(response ~ instruction*type+(inference*type||id), sk2_aff,
+    sk2_aff_kr <- mixed(response ~ instruction*type+(inference||id), sk2_aff,
                         expand_re = TRUE, all_fit = FALSE, method = "KR", 
                         progress=FALSE, type = i)
-    sk2_aff_s <- mixed(response ~ instruction*type+(inference*type||id), sk2_aff,
+    sk2_aff_s <- mixed(response ~ instruction*type+(inference||id), sk2_aff,
                        expand_re = TRUE, all_fit = FALSE, method = "S", 
                        progress=FALSE, type = i)
-    sk2_aff_nkr <- mixed(response ~ instruction*type+(inference*type||id), sk2_aff,
+    sk2_aff_nkr <- mixed(response ~ instruction*type+(inference||id), sk2_aff,
                          progress = FALSE, type = i,
                          expand_re = TRUE, all_fit = FALSE, method = "nested-KR")
-    sk2_aff_lrt <- mixed(response ~ instruction*type+(inference*type||id), sk2_aff,
+    sk2_aff_lrt <- mixed(response ~ instruction*type+(inference||id), sk2_aff,
                          progress = FALSE, type = i,
                          expand_re = TRUE, all_fit = FALSE, method = "LRT")
     sk2_aff_pb <- mixed(response ~ instruction*type+(inference||id), sk2_aff,
